@@ -41,7 +41,7 @@ class TestParticleScattering(BaseTestScattering):
         anim.resume()
         plt.show(block=False)
         plt.pause(1)
-        plt.close()
+        plt.close('all')
 
     def test_animation_tricontourf(self):
         anim = self.particle_plot.animate(
@@ -53,7 +53,7 @@ class TestParticleScattering(BaseTestScattering):
         anim.resume()
         plt.show(block=False)
         plt.pause(1)
-        plt.close()
+        plt.close('all')
 
     def test_tripcolor(self):
         fig, ax = self.particle_plot.plot(
@@ -99,7 +99,7 @@ class TestParticleScattering(BaseTestScattering):
         anim.resume()
         plt.show(block=False)
         plt.pause(1)
-        plt.close()
+        plt.close('all')
 
 
 if __name__ == '__main__':
